import Foundation
import Vapor
import Fluent

class RecommendationsControler: RouteCollection {

    func boot(routes: RoutesBuilder) throws {
        let recommendationRoutes = routes.grouped("api", "recommendations")

        let tokenAuthMiddleware = Token.authenticator()
        let guardAuthMiddleware = User.guardMiddleware()
        let tokenAuthGroup = recommendationRoutes.grouped(tokenAuthMiddleware, guardAuthMiddleware)

        tokenAuthGroup.get(use: getAllHandler)
    }

    func getAllHandler(_ req: Request) async throws -> RecommendendationsResponse {
        let restaurants = try await Restaurant.query(on: req.db).all()
        let tags = try await Tag.query(on: req.db).all()

        let recommender = Recommender(restaurants: restaurants, req: req, tags: tags)

        let recommendedRestaurants = try await recommender.getRecommendations()

        let featuredTags = try await recommender.getUserFeatureVector()
            .sorted { $0.count > $1.count }
            .filter{ $0.count > 0.0 }
            .prefix(10)
            .map { $0.tag }

        var sections: [RecommendedSectionsResponse] = []

        try await featuredTags.asyncForEach { tag in
            let restaurants = Array(recommendedRestaurants
                .filter { $0.tags.contains{ $0.id == tag.id } }
                .prefix(10))
            let response = try await restaurants.asyncMap { restaurant in
                let tags = try await restaurant.$tags.get(on: req.db)
                try await tags.asyncMap { tag in
                    try await tag.$tagCategory.get(on: req.db)
                }
                return try await restaurant.transformToResponse(req)
            }
            let section = RecommendedSectionsResponse(title: tag.name,
                                                      restaurants: response)
            sections.append(section)
        }

        return RecommendendationsResponse(sections: sections)
    }
}

struct RecommendendationsResponse: Content {
    let sections: [RecommendedSectionsResponse]
}

struct RecommendedSectionsResponse: Content {
    let title: String
    let restaurants: [RestaurantResponse]
}
