import Foundation
import Vapor


class VisitsController: RouteCollection {
    func boot(routes: RoutesBuilder) throws {
        let visitsRoutes = routes.grouped("api","visits")
        visitsRoutes.get(use: getAllHandler)


        let tokenAuthMiddleware = Token.authenticator()
        let guardAuthMiddleware = User.guardMiddleware()
        let tokenAuthGroup = visitsRoutes.grouped(tokenAuthMiddleware, guardAuthMiddleware)

        tokenAuthGroup.post(":restaurantID", use: visitRestaurantHandler)
    }

    func getAllHandler(_ req: Request) throws -> EventLoopFuture<[Visit]> {
        Visit.query(on: req.db).all()
    }

    func visitRestaurantHandler(_ req: Request) throws -> EventLoopFuture<EmptyResponse> {
        let restaurantQuery = Restaurant.find(req.parameters.get("restaurantID"), on: req.db).unwrap(or: Abort(.notFound))
        let user = try req.auth.require(User.self)
        return restaurantQuery.flatMap { restaurant in
            restaurant.$visitors.attach(user, on: req.db)
        }.map { EmptyResponse(status: "OK") }
    }
}

struct EmptyResponse: Content {
    let status: String
}
