import Foundation
import FluentKit
import Vapor

final class Tag: Model {

    @ID
    var id: UUID?

    @Field(key: "name")
    var name: String

    @Parent(key: "tagCategoryID")
    var tagCategory: TagCategory

    @Siblings(through: RestaurantTagPivot.self, from: \.$tag, to: \.$restaurant)
    var restaurants: [Restaurant]

    init() { }

    init(id: UUID? = nil, name: String, tagCategoryID: TagCategory.IDValue) {
        self.id = id
        self.name = name
        self.$tagCategory.id = tagCategoryID
    }

    static var schema: String = "tags"
}

extension Tag: Content {
    func transformToResponse(_ req: Request) async throws -> TagResponse {
        let _ = try await self.$tagCategory.get(on: req.db)
        return TagResponse(tag: self)
    }
}

extension Tag {
    static func getOrCreateTag(name: String, categoryID: UUID, _ req: Request) -> EventLoopFuture<Tag> {
        Tag.query(on: req.db).filter(\.$name == name).all()
            .map { tags -> Tag in
                if let tag = tags.first {
                    return tag
                } else {
                    return Tag(name: name, tagCategoryID: categoryID)
                }
            }
            .flatMap { tag in
                tag.save(on: req.db).map { tag }
            }
    }
}

extension Tag: Hashable, Equatable {
    func hash(into hasher: inout Hasher) {
        hasher.combine(id)
    }
}

func ==(left:Tag, right:Tag) -> Bool {
    return left.id == right.id
}


struct TagResponse: Content {
    let id: UUID?
    let name: String
    let tagCategory: TagCategory

    init(tag: Tag) {
        self.id = tag.id
        self.name = tag.name
        self.tagCategory = tag.tagCategory
    }
}
