import Foundation
import FluentKit
import Vapor

final class TagCategory: Model {

    @ID
    var id: UUID?

    @Field(key: "name")
    var name: String

    @Children(for: \.$tagCategory)
    var tags: [Tag]

    init() { }

    init(id: UUID? = nil, name: String) {
        self.id = id
        self.name = name
    }

    static var schema: String = "tag-categories"
}

extension TagCategory: Content { }

extension TagCategory {
    static func getOrCreateTagCategory(name: String,_ req: Request) -> EventLoopFuture<TagCategory> {
        TagCategory
            .query(on: req.db).filter(\.$name == name)
            .all()
            .map { tagCategories -> TagCategory in
                if let tagCategory = tagCategories.first {
                    return tagCategory
                } else {
                    return TagCategory(name: name)
                }
            }.flatMap { tagCategory in
                tagCategory.save(on: req.db).map { tagCategory }
            }
    }
}
