//
//  APISession.swift
//  Eating Barna
//
//  Created by Joan Martin on 24/5/22.
//

import Combine
import Foundation

struct APISession: APIService {
    static let shared = APISession()
    func request<T: Decodable>(with endpoint: Endpoint) async throws -> T {

        let decoder = JSONDecoder()
        decoder.keyDecodingStrategy = .convertFromSnakeCase



        guard let url = URLComponents(string: "http://\(endpoint.baseURL)\(endpoint.path)")?.url else {
            throw APIError.unknown
        }

        var urlRequest = URLRequest(url: url)

        endpoint.headers.forEach { key, value in
            urlRequest.setValue(value, forHTTPHeaderField: key)
        }

        urlRequest.httpMethod = endpoint.method

        if let body = endpoint.body {
            let jsonDataBody = try? JSONSerialization.data(withJSONObject: body)

            urlRequest.httpBody = jsonDataBody
        }
        NetworkLogger.log(request: urlRequest)

        let session = URLSession(configuration: .default)

        let (data, response) = try await session.data(for: urlRequest)

        guard let httpResponse = response as? HTTPURLResponse else {
            throw APIError.unknown
        }

        NetworkLogger.log(response: httpResponse, data: data, error: nil)

        if !(200...299).contains(httpResponse.statusCode) {
            throw APIError.httpError(httpResponse.statusCode)
        }

        do {
            return try decoder.decode(T.self, from: data)
        } catch {
            throw APIError.decodingError
        }
    }
}
