//
//  EatingBarnaService.swift
//  Eating Barna
//
//  Created by Joan Martin on 24/5/22.
//

import Foundation
import Combine

class EatingBarnaService {
    let apiSession: APIService = APISession()

    static let shared = EatingBarnaService()

    func login(email: String, password: String) async throws -> TokenResponse {
        return try await apiSession.request(with: EatingBarnaEndpoint.login(email: email, password: password))
    }

    func getAllRestaurants() async throws -> RestaurantsResponse {
        return try await apiSession.request(with: EatingBarnaEndpoint.getRestaurants)
    }

    func getRecommendations() async throws -> SectionsResponse {
        return try await apiSession.request(with: EatingBarnaEndpoint.getRecommendations)
    }

    func postVisit(restaurantID: String) async throws -> EmptyResponse {
        return try await apiSession.request(with: EatingBarnaEndpoint.postVisit(restaurantID: restaurantID))
    }

    func getTagCategories() async throws -> [TagCategoryResponse]  {
        return try await apiSession.request(with: EatingBarnaEndpoint.getTagCategories)
    }

    func postUser(name: String, surname: String, email: String, password: String) async throws -> UserResponse {
        return try await apiSession.request(with: EatingBarnaEndpoint.postUser(name: name, surname: surname, email: email, password: password))
    }

    func getFavoriteTags() async throws -> [TagResponse] {
        return try await apiSession.request(with: EatingBarnaEndpoint.getFavoriteTags)
    }

    func postFavoriteTags(tags: [Tag]) async throws -> [TagResponse] {
        return try await apiSession.request(with: EatingBarnaEndpoint.postFavoriteTags(tags: tags.map { $0.id }))
    }

    func postFavoriteRestaurant(id: String) async throws -> RestaurantResponse {
        return try await apiSession.request(with: EatingBarnaEndpoint.postFavoriteRestaurant(id: id))
    }

    func deleteFavoriteRestaurant(id: String) async throws -> RestaurantResponse {
        return try await apiSession.request(with: EatingBarnaEndpoint.deleteFavoriteRestaurant(id: id))
    }
}
