//
//  TextFields.swift
//  Eating Barna
//
//  Created by Joan Martin Martrus on 26/4/22.
//

import SwiftUI

struct AppTextField: View {
    @FocusState var isSelected: Bool
    @Binding var input: String
    let placeHolderText: String
    let systemImageName: String
    let color: Color
    let correctInput: Bool

    private var currentColor: Color {
        return (!correctInput && isSelected) ? .red : color
    }
    
    
    var body: some View {
        HStack {
            Image(systemName: systemImageName)
            TextField(placeHolderText, text: $input)
                .autocapitalization(.none)
                .disableAutocorrection(true)
                .foregroundColor(currentColor)
                .font(.montserratRegular())
                .focused($isSelected)
        }
        .underlineTextField(focused: isSelected, withColor: currentColor)
    }

    init(input: Binding<String>, placeHolderText: String, systemImageName: String, color: Color = .textFieldGray, correctInput: Bool = true) {
        self._input = input
        self.placeHolderText = placeHolderText
        self.systemImageName = systemImageName
        self.color = color
        self.correctInput = correctInput
    }
}

struct AppSecureTextField: View {
    @FocusState var isSelected: Bool
    @Binding var input: String
    let placeHolderText: String
    let systemImageName: String
    let color: Color

    var correctInput: Bool {
        return input.count >= 8
    }

    private var currentColor: Color {
        return (!correctInput && isSelected) ? .red : color
    }
    
    
    var body: some View {
        HStack {
            Image(systemName: systemImageName)
            SecureField(placeHolderText, text: $input)
                .font(.montserratRegular())
                .focused($isSelected)
        }
        .underlineTextField(focused: isSelected, withColor: currentColor)
    }
}


struct TextFields_Previews: PreviewProvider {
    static var previews: some View {
        AppTextField(input: .constant(""), placeHolderText: "Email", systemImageName: "person", color: .textFieldGray).previewLayout(.sizeThatFits)
        AppSecureTextField(input: .constant("124567"), placeHolderText: "Contraseña", systemImageName: "lock", color: .textFieldGray).previewLayout(.sizeThatFits)
    }
}
