//
//  Buttons.swift
//  Eating Barna
//
//  Created by Joan Martin Martrus on 29/4/22.
//

import SwiftUI

struct PrimaryButton: View {
    let text: String
    let action: () -> ()
    let isDisabled: Bool

    init(text: String, isDisabled: Bool = false, action: @escaping () -> () = {}) {
        self.text = text
        self.action = action
        self.isDisabled = isDisabled
    }
    
    var body: some View {
        Button {
            action()
        } label: {
            Text(text)
                .font(.montserratBold(ofSize: 17.0))
                .padding(.vertical, 8.0)
                .padding(.horizontal, 16.0)
        }
        .disabled(isDisabled)
        .background(isDisabled ? .gray: .black)
        .clipShape(Capsule(style: .continuous))
        .foregroundColor(.white)
    }
}


struct SecondaryButton: View {
    let text: String
    let action: () -> ()
    
    init(text: String, action: @escaping () -> () = {}) {
        self.text = text
        self.action = action
    }
    
    var body: some View {
        Button {
            action()
        } label: {
            Text(text)
                .font(.montserratBold(ofSize: 17.0))
                .padding(.vertical, 8.0)
                .padding(.horizontal, 16.0)
        }
        .background(.white)
        .foregroundColor(.black)
        .overlay(
            Capsule(style: .continuous)
                .stroke(.black, lineWidth: 2.0)
        )
        .clipShape(Capsule(style: .continuous))
    }
}


struct Buttons_Previews: PreviewProvider {
    static var previews: some View {
        PrimaryButton(text: "Ejemplo").previewLayout(.sizeThatFits).padding()
        SecondaryButton(text: "Ejemplo").previewLayout(.sizeThatFits).padding()

    }
}
