//
//  FilterGroupView.swift
//  Eating Barna
//
//  Created by Joan Martin on 29/5/22.
//

import SwiftUI

struct FilterGroupView: View {
    let tagCategory: TagCateogry
    let isSelected = false
    @Binding var selectedTags: [Tag]

    let cols = [
        GridItem(.adaptive(minimum: 80))
    ]

    var body: some View {
        ScrollView {
            LazyVGrid(columns: cols) {
                ForEach(tagCategory.tags) { tag in
                    FilterItemView(tag: tag, isSelected: selectedTags.contains { $0.id == tag.id })
                        .onTapGesture {
                            withAnimation {
                                toggleSelection(of: tag)
                            }
                        }
                }
            }
        }
    }

    private func toggleSelection(of tag: Tag) {
        if selectedTags.contains(where: { $0.id == tag.id }) {
            selectedTags.removeAll { $0.id == tag.id }
        } else {
            selectedTags.append(tag)
        }
    }

    init(tagCategory: TagCateogry, selectedTags: Binding<[Tag]>) {
        self.tagCategory = tagCategory
        self._selectedTags = selectedTags
    }
}

struct FilterGroupView_Previews: PreviewProvider {
    static var previews: some View {
        FilterGroupView(tagCategory: MockData.tagCategory1, selectedTags: .constant([]))
    }
}



struct FilterItemView: View {
    let tag: Tag
    let isSelected: Bool

    var body: some View {
        Text(tag.name)
            .frame(height: 32, alignment: .center)
            .lineLimit(1)
            .font(.montserratBold(ofSize: 12))
            .foregroundColor(isSelected ? .white : .black)
            .padding(.horizontal, 8.0)
            .minimumScaleFactor(0.01)
            .background(
                Capsule(style: .continuous)
                    .strokeBorder(Color.black,lineWidth: 1.0)
                    .background(isSelected ? .black : .white)
                    .clipped()
            )
            .clipShape(Capsule(style: .continuous))
    }

}
