//
//  FiltersView.swift
//  Eating Barna
//
//  Created by Joan Martin on 29/5/22.
//

import SwiftUI

struct FiltersView: View {
    @ObservedObject var viewModel = FiltersViewModel()
    @Environment(\.presentationMode) var presentationMode
    @State var selectedTags: [Tag] = []
    let onApplyFilters: ([Tag]) -> ()

    var body: some View {
        ZStack {
            ScrollView {
                VStack(spacing: 20) {
                    ForEach(viewModel.tagCategories) { tagCategory in
                        FilterGroupView(tagCategory: tagCategory, selectedTags: $selectedTags)
                        Divider()
                    }
                }.padding()
            }
            VStack {
                Spacer()
                HStack {
                    PrimaryButton(text: "Filtrar") {
                        onApplyFilters(selectedTags)
                        presentationMode.wrappedValue.dismiss()
                    }.shadow(radius: 4.0)
                    SecondaryButton(text: "Limpiar filtros") {
                        withAnimation {
                            self.selectedTags = []
                        }
                    }.shadow(radius: 4.0)
                }
            }
        }.task {
            await viewModel.onAppear()
        }
    }

    init(selectedTags: [Tag] = [], onApplyFilters: @escaping ([Tag]) -> () = { tags in }) {
        self.onApplyFilters = onApplyFilters
        self._selectedTags = State(initialValue: selectedTags)
    }
}

struct FiltersView_Previews: PreviewProvider {
    static var previews: some View {
        FiltersView()
    }
}
