//
//  HomeViewModel.swift
//  Eating Barna
//
//  Created by Joan Martin Martrus on 29/4/22.
//

import Foundation
import Combine
import SwiftUI


class HomeViewModel: ObservableObject {
    @Published var homeSections: [HomeSection] = []
    @Published var isLoading: Bool = false
    let eatingBarnaService = EatingBarnaService.shared
    private var navigationManager = NavigationManager.shared

    init(homeSections: [HomeSection] = [], isLoading: Bool = false, navigationManager: NavigationManager = NavigationManager.shared) {
        self.homeSections = homeSections
        self.isLoading = isLoading
        self.navigationManager = navigationManager
    }

    @MainActor
    func onAppear() async {
        do {
            self.homeSections = try await eatingBarnaService.getRecommendations().sections.map { HomeSection(sectionResponse: $0) }
        } catch let error as APIError {
            switch error {
            case .decodingError, .unknown:
                print(error.localizedDescription)
            case .httpError(let code):
                return
                if code == 401 { navigationManager.currentView = .login }
            }
        } catch {
            print(error.localizedDescription)
        }
    }
}
