//
//  ContentView.swift
//  Eating Barna
//
//  Created by Joan Martin Martrus on 25/4/22.
//

import SwiftUI

struct LoginView: View {
    @ObservedObject var viewModel = LoginViewModel()
//    @ObservedObject var navigationManager = NavigationManager.shared
    
    @State var email = ""
    @State var password = ""

    var showError: Bool {
        return viewModel.loginError != nil
    }

    var isEmailCorrect: Bool {
        let emailFormat = "(?:[\\p{L}0-9!#$%\\&'*+/=?\\^_`{|}~-]+(?:\\.[\\p{L}0-9!#$%\\&'*+/=?\\^_`{|}" + "~-]+)*|\"(?:[\\x01-\\x08\\x0b\\x0c\\x0e-\\x1f\\x21\\x23-\\x5b\\x5d-\\" + "x7f]|\\\\[\\x01-\\x09\\x0b\\x0c\\x0e-\\x7f])*\")@(?:(?:[\\p{L}0-9](?:[a-" + "z0-9-]*[\\p{L}0-9])?\\.)+[\\p{L}0-9](?:[\\p{L}0-9-]*[\\p{L}0-9])?|\\[(?:(?:25[0-5" + "]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-" + "9][0-9]?|[\\p{L}0-9-]*[\\p{L}0-9]:(?:[\\x01-\\x08\\x0b\\x0c\\x0e-\\x1f\\x21" + "-\\x5a\\x53-\\x7f]|\\\\[\\x01-\\x09\\x0b\\x0c\\x0e-\\x7f])+)\\])"
           let emailPredicate = NSPredicate(format:"SELF MATCHES %@", emailFormat)
           return emailPredicate.evaluate(with: email)
    }

    var body: some View {
        ZStack{
            Color.white
            VStack {
                Image("eatinBarnaLogoNoText")
                    .renderingMode(.template)
                    .resizable()
                    .aspectRatio( contentMode: .fit)
                    .foregroundColor(.black)
                    .frame(width: UIScreen.main.bounds.width, height: UIScreen.main.bounds.height / 3.0)
                VStack {
                    AppTextField(input: $email, placeHolderText: "Email", systemImageName: "person", color: .textFieldGray, correctInput: self.isEmailCorrect)
                    AppSecureTextField(input: $password, placeHolderText: "Contraseña", systemImageName: "lock", color: .textFieldGray)
                }
                .padding()
                
                PrimaryButton(text: "ENTRAR") {
                    Task {
                        await viewModel.onLoginButtonTapped(email: email, password: password)
                    }
                }
                
                HStack {
                    Text("¿No te has registrado aún?")
                        .font(.montserratRegular(ofSize: 12.0))
                        .foregroundColor(.black)
                    Button {
                        viewModel.onResgisterButtonTapped()
                    } label: {
                        Text("Regístrate!")
                            .font(.montserratBold(ofSize: 12.0))
                            .foregroundColor(.black)
                    }
                }
                Spacer()
            }.blur(radius: viewModel.isLoading ? 2.0 : 0.0 )
            LoadingView(isLoading: $viewModel.isLoading)
        }.padding(.vertical, 40.0)
            .onAppear {
                #if DEBUG
                email = "joan71995@gmail.com"
                password = "123456789"
                #endif
            }
            .alert(viewModel.loginTitleError, isPresented: $viewModel.loginErrorEnabled) {
                Button("OK", role: .cancel) { }
            }
    }
}

struct LoginView_Previews: PreviewProvider {
    static var previews: some View {
        LoginView()
    }
}

