//
//  LoginViewModel.swift
//  Eating Barna
//
//  Created by Joan Martin Martrus on 29/4/22.
//

import Foundation
import Combine
import SwiftUI


class LoginViewModel: ObservableObject {
    var cancellables = Set<AnyCancellable>()
    let navigationManager = NavigationManager.shared
    let userDefaultsManager = UserDefaultsManager.shared

    @Published var loginError: APIError? = nil {
        didSet {
            loginErrorEnabled = loginError != nil 
        }
    }

    @Published var loginErrorEnabled = false

    @Published var isLoading: Bool = false

    var loginTitleError: String {
        guard let loginError = loginError else {
            return ""
        }
        switch loginError {
        case .decodingError:
            return "Algo no ha ido como esperábamos, compruebe que tiene conexión a internet y vuelve a intentarlo."
        case .httpError(let statusCode):
            return statusCode == 401 ? "El usuario y/o contraseña introducidos no son correctos." : "Algo no ha ido como esperábamos, compruebe que tiene conexión a internet y vuelve a intentarlo."
        case .unknown:
            return "Algo no ha ido como esperábamos, compruebe que tiene conexión a internet y vuelve a intentarlo."
        }
    }

    init() {
    }

    @MainActor
    func onLoginButtonTapped(email: String, password: String) async {
        isLoading = true
        do {
            let tokenResponse = try await EatingBarnaService.shared.login(email: email, password: password)
            self.userDefaultsManager.save(value: tokenResponse.value, with: .token)
            self.navigationManager.currentView = .tabbar
        } catch let error as APIError {
            self.loginError = error
        } catch {
            print("unknown error")
        }
        isLoading = false
    }
    
    func onResgisterButtonTapped() {
        withAnimation {
            navigationManager.currentView = .register
        }

    }
}

