//
//  MapDetailView.swift
//  Eating Barna
//
//  Created by Joan Martin Martrus on 2/5/22.
//

import SwiftUI

struct MapDetailView: View {
    let restaurant: Restaurant
    @State var startHeight: Double? = nil
    @State var draggedHeight: Double = 0.0
    
    @Binding var isPresented: Bool
    
    
    var drag: some Gesture {
        DragGesture()
            .onChanged { value in
                if let startHeight = startHeight {
                    draggedHeight = (value.location.y - startHeight) > 0 ? value.location.y - startHeight : 0.0
                } else {
                    startHeight = value.location.y
                }
            }.onEnded { value in
                if draggedHeight >= 50.0 {
                    isPresented = false
                } else {
                    startHeight = nil
                    draggedHeight = 0.0
                }
            }

    }
    
    var body: some View {
        VStack {
            Spacer()
            VStack {
                Capsule().frame(width: UIScreen.main.bounds.size.width / 4.0, height: 4.0, alignment: .center)
                    .foregroundColor(.black)
                    .padding(.bottom)
                HStack {
                    Image("testImage")
                        .resizable()
                        .aspectRatio(contentMode: .fill)
                        .clipped()
                        .frame(width: 124, height: 124, alignment: .center)
                        .cornerRadius(6.0)
                    VStack (alignment: .leading){
                        Text(self.restaurant.title)
                            .font(.montserratBold(ofSize: 24.0))
                        Text(self.restaurant.place)
                            .font(.montserratMedium(ofSize: 17.0))
                        Text("\(self.restaurant.price)")
                            .font(.montserratMedium(ofSize: 17.0))
                            .foregroundColor(.gray)
                    }
                    Spacer()
                }
            }
            .padding()
            .background(.white)
            .cornerRadius(20.0, corners: [.topLeft,.topRight])
            .offset(y: draggedHeight)
            .gesture(drag)
            
        }.background(.clear)
    }

}

struct MapDetailView_Previews: PreviewProvider {
    static var previews: some View {
        MapDetailView(restaurant: Restaurant(id: "1", title: "El meu kebak", place: "Horta"), isPresented: .constant(true))
    }
}
