//
//  MapView.swift
//  Eating Barna
//
//  Created by Joan Martin Martrus on 1/5/22.
//

import SwiftUI
import MapKit


struct MapView: View {
    @State private var mapRegion = MKCoordinateRegion(center: CLLocationCoordinate2D(latitude: 41.390205, longitude: 2.154007), span: MKCoordinateSpan(latitudeDelta: 0.2,longitudeDelta: 0.2))
    @State var selectedRestaurant: Restaurant? = nil
    @State var isPresented = false
    @State var presentFilters = false
    @ObservedObject var viewModel = MapViewModel()

    var body: some View {
        ZStack {
            VStack {
                HStack {
                    AppTextField(input: $viewModel.searchText, placeHolderText: "Introduce el nombre del restaurante...", systemImageName: "magnifyingglass")
                    Button {
                        presentFilters = true
                    } label: {
                        Image(systemName: "slider.horizontal.3")
                    }.foregroundColor(.textFieldGray)

                }.padding(.horizontal)
                Map(coordinateRegion: $mapRegion, annotationItems: viewModel.filteredRestaurants) { restaurant in
                    MapAnnotation(coordinate: restaurant.coordinates!) {
                        EatingBarnaMapMarker()
                            .onTapGesture {
                                withAnimation {
                                    self.selectedRestaurant = restaurant
                                    self.isPresented = true
                                }
                            }
                    }
                }
            }
            VStack {
                Spacer()
                if isPresented, let selectedRestaurant = selectedRestaurant {
                    MapDetailView(restaurant: selectedRestaurant, isPresented: $isPresented)
                        .shadow(radius: 5.0)
                        .frame(width: UIScreen.main.bounds.size.width)
                    .transition(.move(edge: .bottom))
                }
            }
        }.sheet(isPresented: $presentFilters) {
            FiltersView(selectedTags: viewModel.selectedTags) { tags in
                withAnimation {
                    viewModel.selectedTags = tags
                }
            }
        }.task {
            await viewModel.onAppear()
        }
    }
    
}

struct MapView_Previews: PreviewProvider {
    static var previews: some View {
        MapView()
    }
}



