//
//  MapViewModel.swift
//  Eating Barna
//
//  Created by Joan Martin Martrus on 1/5/22.
//

import Foundation
import Combine

@MainActor
class MapViewModel: ObservableObject {

    private var suscriptions: Set<AnyCancellable> = []

    @Published var allRestaurants: [Restaurant] = [] {
        didSet {
            restaurantsToShow = allRestaurants
        }
    }

    private let navigationManager = NavigationManager.shared

    @Published var restaurantsToShow: Restaurants = []


    @Published var searchText: String = ""

    @Published var selectedTags: [Tag] = []

    var filteredRestaurants : Restaurants {
        if selectedTags.isEmpty {
            return restaurantsToShow.filter { $0.coordinates != nil }
        } else {
            return restaurantsToShow.filter { restaurant in
                let tags = restaurant.tags ?? []
                return tags.reduce(false) { partialResult, tag in
                    return partialResult || selectedTags.contains { $0.id == tag.id }
                }
            }.filter { $0.coordinates != nil }
        }
    }
    
    init() {
        $searchText
            .map { $0 }
            .sink { completion in
                switch completion {
                case .failure:
                    debugPrint("fail")
                case .finished:
                    debugPrint("finished")
                }
            } receiveValue: { searchText in
                if searchText.count < 1 {
                    self.restaurantsToShow = self.allRestaurants
                } else {
                    self.restaurantsToShow = self.allRestaurants.filter { $0.title.lowercased().contains(searchText.lowercased()) }
                }
            }.store(in: &suscriptions)
    }

    func onAppear() async {
        do {
            self.allRestaurants = try await EatingBarnaService.shared.getAllRestaurants().map { Restaurant(restaurantResponse: $0) }
        } catch let error as APIError {
            switch error {
            case .decodingError:
                print(error.localizedDescription)
            case .httpError(let code):
                if code == 401 { self.navigationManager.currentView = .login }
            case .unknown:
                print(error.localizedDescription)

            }
        } catch {
            print(error.localizedDescription)
        }
    }
}
