//
//  ProfileView.swift
//  Eating Barna
//
//  Created by Joan Martin Martrus on 1/5/22.
//

import SwiftUI

struct ProfileView: View {
    @ObservedObject var viewModel: ProfileViewModel = ProfileViewModel()
    @State var presentZonesView: Bool = false
    @State var presentFavoriteFoodView: Bool = false
    @State var showingAlert: Bool = false
    
    var body: some View {
        VStack {
            UserProfileImageView(name: viewModel.user.name, email: viewModel.user.email)
            List {
                Section {
                    ProfileRowItemView(image: "fork.knife", title: "Editar gustos").onTapGesture {
                        self.presentFavoriteFoodView = true
                    }
                    ProfileRowItemView(image: "map.fill", title: "Editar zonas").onTapGesture {
                        self.presentZonesView = true
                    }
                }
                Section {
                    ProfileRowItemView(image: "rectangle.portrait.and.arrow.right", title: "Salir")
                        .onTapGesture {
                            showingAlert = true
                        }
                        .alert("¿Está seguro de que desea salir?", isPresented: $showingAlert) {
                            Button("Si", role: .destructive) {
                                showingAlert = false
                                viewModel.onLogoutButtonTapped() }
                            Button("No", role: .cancel) {
                                showingAlert = false
                            }
                    }

                }
            }
        }
        .background(Color(UIColor.systemGroupedBackground))
        .sheet(isPresented: $presentZonesView) {
            QuestionaryView(viewModel: QuestionaryViewModel(questionaryType: .neighbourhood, isSheet: true))
        }
        .sheet(isPresented: $presentFavoriteFoodView) {
            QuestionaryView(viewModel: QuestionaryViewModel(questionaryType: .foodType, isSheet: true))
        }
    }
}

struct ProfileView_Previews: PreviewProvider {
    static var previews: some View {
        ProfileView()
    }
}
