//
//  QuestionaryView.swift
//  Eating Barna
//
//  Created by Joan Martin on 6/6/22.
//

import SwiftUI

struct QuestionaryView: View {
    @ObservedObject var viewModel: QuestionaryViewModel
    @Environment(\.presentationMode) var presentationMode

    var body: some View {
        VStack {
            Text(viewModel.question)
                .font(.montserratBold(ofSize: 20))
            if let tagCategory = viewModel.tagCategory {
                FilterGroupView(tagCategory: tagCategory, selectedTags: $viewModel.favoriteTags)
            }
            PrimaryButton(text: "Aceptar") {
                Task {
                    await viewModel.onNextButtonTapped()
                }
            }
            Spacer()
        }
        .onReceive(viewModel.dismissSubjectPublisher, perform: { _ in
            presentationMode.wrappedValue.dismiss()
        })
        .padding()
        .task {
            await viewModel.onAppear()
        }
    }

    init(viewModel: QuestionaryViewModel) {
        self.viewModel = viewModel
    }
}

struct QuestionaryView_Previews: PreviewProvider {
    static var previews: some View {
        QuestionaryView(viewModel: QuestionaryViewModel(questionaryType: .neighbourhood))
    }
}
