//
//  QuestionaryViewModel.swift
//  Eating Barna
//
//  Created by Joan Martin on 6/6/22.
//

import Foundation
import Combine

@MainActor
class QuestionaryViewModel: ObservableObject {
    private let questionaryType: QuestionaryType
    private let apiSession: EatingBarnaService = EatingBarnaService.shared
    private let navigationManager = NavigationManager.shared

    private let dissmissSubject = PassthroughSubject<Void, Never>()

    var dismissSubjectPublisher: AnyPublisher<Void, Never> {
        return dissmissSubject.eraseToAnyPublisher()
    }

    private var cancellables = Set<AnyCancellable>()

    @Published var tagCategory: TagCateogry? = nil
    @Published var favoriteTags: [Tag] = []
    let isSheet: Bool

    var tags: [Tag] {
        guard let tagCategory = tagCategory else {
            return []
        }
        return tagCategory.tags
    }

    var question: String {
        questionaryType.question
    }

    func onNextButtonTapped() async {
        do {
            let _ = try await apiSession.postFavoriteTags(tags: favoriteTags)
            if self.isSheet {
                self.dissmissSubject.send()
                self.dissmissSubject.send(completion: .finished)
            } else {
                self.navigationManager.currentView = questionaryType.nextView
            }
        } catch let error as APIError {
            print(error.localizedDescription)
        } catch {
            print(error.localizedDescription)
        }
    }

    init(questionaryType: QuestionaryType, isSheet: Bool = false) {
        self.isSheet = isSheet
        self.questionaryType = questionaryType
    }

    func onAppear() async {
        do {
            (self.tagCategory, self.favoriteTags) = (
                try await apiSession.getTagCategories()
                    .filter { $0.name == self.questionaryType.filterString }
                    .map { TagCateogry(tagCategoryResponse: $0) }
                    .first,
                try await apiSession.getFavoriteTags()
                    .map { Tag(tagReponse: $0) }
            )
            guard let tagCategory = tagCategory else {
                return
            }
            print(tagCategory, favoriteTags)

        } catch let error as APIError {
            print(error.localizedDescription)
        } catch {
            print(error.localizedDescription)
        }
    }
}
