//
//  RegisterViewModel.swift
//  Eating Barna
//
//  Created by Joan Martin on 3/6/22.
//

import Foundation
import SwiftUI
import Combine

@MainActor
class RegisterViewModel: ObservableObject {
    @Published var name: String = ""
    @Published var surname: String = ""
    @Published var email: String = ""
    @Published var password: String = ""
    @Published var verifiedPassword: String = ""

    @Published var showNextScreen: Bool = false

    let navigationManager = NavigationManager.shared

    private let apiService = EatingBarnaService.shared

    private var cancellables = Set<AnyCancellable>()

    private let userDefaultsManager = UserDefaultsManager.shared

    var nameIsCorrect: Bool {
        return !name.isEmpty
    }

    var surnameIsCorrect: Bool {
        return !surname.isEmpty
    }

    var emailIsCorrect: Bool {
        let emailFormat = "(?:[\\p{L}0-9!#$%\\&'*+/=?\\^_`{|}~-]+(?:\\.[\\p{L}0-9!#$%\\&'*+/=?\\^_`{|}" + "~-]+)*|\"(?:[\\x01-\\x08\\x0b\\x0c\\x0e-\\x1f\\x21\\x23-\\x5b\\x5d-\\" + "x7f]|\\\\[\\x01-\\x09\\x0b\\x0c\\x0e-\\x7f])*\")@(?:(?:[\\p{L}0-9](?:[a-" + "z0-9-]*[\\p{L}0-9])?\\.)+[\\p{L}0-9](?:[\\p{L}0-9-]*[\\p{L}0-9])?|\\[(?:(?:25[0-5" + "]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-" + "9][0-9]?|[\\p{L}0-9-]*[\\p{L}0-9]:(?:[\\x01-\\x08\\x0b\\x0c\\x0e-\\x1f\\x21" + "-\\x5a\\x53-\\x7f]|\\\\[\\x01-\\x09\\x0b\\x0c\\x0e-\\x7f])+)\\])"
           let emailPredicate = NSPredicate(format:"SELF MATCHES %@", emailFormat)
           return emailPredicate.evaluate(with: email)
    }

    var passwordIsCorrect: Bool {
        return password.count >= 8
    }

    var verifiedPasswordIsCorrect: Bool {
        return password.count >= 8
    }

    var allFieldsAreCorrect: Bool {
        return verifiedPasswordIsCorrect && passwordIsCorrect && (password == verifiedPassword) && nameIsCorrect && surnameIsCorrect && emailIsCorrect
    }

    func onBackButtonPressed() {
        withAnimation {
            navigationManager.currentView = .login
        }
    }

    func onRegisterFinishedSuccesfully() async {
        do {
            let tokenResposne = try await apiService.login(email: email, password: password)
            self.userDefaultsManager.save(value: tokenResposne.value, with: .token)
            self.navigationManager.currentView = .questionary(questionaryType: .neighbourhood)
        } catch let error as APIError {
            print(error.localizedDescription)
        } catch {
            print(error.localizedDescription)
        }
    }

    func onRegisterButtonTapped() async {
        do {
            let user = try await apiService.postUser(name: name, surname: surname, email: email, password: password)
            await self.onRegisterFinishedSuccesfully()
        } catch let error as APIError {
            print(error.localizedDescription)
        } catch {
            print(error.localizedDescription)
        }
    }
}
