//
//  RestaurantCardView.swift
//  Eating Barna
//
//  Created by Joan Martin Martrus on 29/4/22.
//

import SwiftUI

struct RestaurantCardView: View {
    @ObservedObject var viewModel: RestaurantCardViewModel
    let color: Color = .white

    var body: some View {
        GeometryReader { metrics in
            ZStack {
                color
                VStack (alignment: .leading){
                    AsyncImage(url: URL(string: viewModel.restaurant.imageURL)) { image in
                        image
                            .resizable()
                            .aspectRatio( contentMode: .fill)
                            .frame(width: metrics.size.width, height: 2.0 * metrics.size.height / 3.0)
                            .clipped()
                    } placeholder: {
                        Color.gray.opacity(0.5)
                            .frame(width: metrics.size.width, height: 2.0 * metrics.size.height / 3.0)
                    }
                    HStack {
                        VStack (alignment: .leading){
                            Spacer()
                            Text(viewModel.restaurant.title)
                                .font(.montserratBold(ofSize: 20.0))
                            Text(viewModel.restaurant.place)
                                .font(.montserratRegular())
                            Text(viewModel.restaurant.price)
                                .font(.montserratMedium())
                                .foregroundColor(.textGray)
                            Spacer()
                        }
                        Spacer()
                        FavoriteButton(isFavorite: $viewModel.restaurant.isFavorite) {
                            Task {
                                await viewModel.onFavoriteButtonPressed()
                            }
                        }
                    }.padding(.horizontal)
                }
            }
        }.cornerRadius(6.0)
        .shadow(radius: 2.0)
        .padding(.vertical, 4.0)
    }

    init(viewModel: RestaurantCardViewModel) {
        self.viewModel = viewModel
    }
}


struct FavoriteButton: View {
    @Binding var isFavorite: Bool?
    let action: () -> ()

    var body: some View {
        Button {
            action()
            isFavorite?.toggle()
        } label: {
            Image(systemName: (isFavorite ?? false) ? "heart.fill" : "heart")
                .tint((isFavorite ?? false) ? .red : .gray)
        }
    }

}

struct RestaurantCardView_Previews: PreviewProvider {
    static var previews: some View {
        RestaurantCardView(viewModel: RestaurantCardViewModel(restaurant: MockData.restaurant1)).previewLayout(.sizeThatFits).padding()
    }
}

