//
//  RestaurantCardViewModel.swift
//  Eating Barna
//
//  Created by Joan Martin on 9/12/22.
//

import Foundation
import Combine

class RestaurantCardViewModel: ObservableObject {
    @Published var restaurant: Restaurant

    var cancellables: Set<AnyCancellable> = []

    init(restaurant: Restaurant) {
        self.restaurant = restaurant
        self.restaurant.$isFavorite.sink { isFavorite in
            self.objectWillChange.send()
        }.store(in: &cancellables)
    }

    @MainActor
    func onFavoriteButtonPressed() async {
        guard let isFavorite = restaurant.isFavorite else { return }
        do {
            if isFavorite {
                self.restaurant = Restaurant(restaurantResponse: try await EatingBarnaService.shared.postFavoriteRestaurant(id: restaurant.id))
            } else {
                self.restaurant = Restaurant(restaurantResponse: try await EatingBarnaService.shared.deleteFavoriteRestaurant(id: restaurant.id))
            }
        } catch let error as APIError {
            print(error.localizedDescription)
            restaurant.isFavorite?.toggle()
        } catch {
            print(error.localizedDescription)
            restaurant.isFavorite?.toggle()
        }

    }
}
