//
//  RestaurantDetail.swift
//  Eating Barna
//
//  Created by Joan Martin Martrus on 3/5/22.
//

import SwiftUI

struct RestaurantDetail: View {
    @Environment(\.presentationMode) var presentationMode
    
    @ObservedObject var viewModel: RestaurantDetailViewModel

    var body: some View {
        ZStack {
            ScrollView {
                VStack(alignment: .leading) {
                    AsyncImage(url: URL(string: viewModel.restaurant.imageURL)) { image in
                        image
                            .resizable()
                            .aspectRatio(contentMode: .fill)
                            .frame(width: UIScreen.main.bounds.size.width, height: UIScreen.main.bounds.size.width, alignment: .center)
                            .clipped()
                    } placeholder: {
                        Color.gray.opacity(0.5)
                            .aspectRatio(contentMode: .fill)
                            .frame(width: UIScreen.main.bounds.size.width, height: UIScreen.main.bounds.size.width, alignment: .center)
                    }
                    VStack(alignment: .leading, spacing: 32.0) {
                        Text(viewModel.restaurant.title)
                            .font(.montserratBold(ofSize: 24.0))
                        Text(viewModel.restaurant.price)
                            .font(.montserratBold(ofSize: 17.0))
                        Text(viewModel.restaurant.description)
                            .font(.montserratMedium(ofSize: 17.0))
                        RestaurantDetailMapView(restaurant: viewModel.restaurant).frame(width: .infinity, height: 200, alignment: .center)
                    }.padding()
                }
            }.ignoresSafeArea()
            VStack {
                HStack {
                    Button {
                        presentationMode.wrappedValue.dismiss()
                    } label: {
                        Image(systemName: "x.circle.fill")
                            .resizable()
                            .frame(width: 32.0, height: 32.0, alignment: .center)
                            .foregroundColor(.black).background(.white)
                            .clipShape(Circle())
                    }
                    Spacer()
                }
                Spacer()
            }.padding(.horizontal)
        }.task {
            await viewModel.onAppear()
        }
    }
}

struct RestaurantDetail_Previews: PreviewProvider {
    static var previews: some View {
        RestaurantDetail(viewModel: RestaurantDetailViewModel(restaurant: MockData.restaurant1))
    }
}
