//
//  SearchView.swift
//  Eating Barna
//
//  Created by Joan Martin Martrus on 30/4/22.
//

import SwiftUI

struct SearchView: View {
    @ObservedObject private var viewModel: SearchViewModel = SearchViewModel()
    @State var presentFilters: Bool = false
    @State var restaurantToPresent: Restaurant? = nil

    
    var body: some View {
        GeometryReader { metrics in
            VStack {
                HStack {
                    AppTextField(input: $viewModel.searchText, placeHolderText: "Introduce el nombre del restaurante...", systemImageName: "magnifyingglass")
                    Button {
                        presentFilters = true
                    } label: {
                        Image(systemName: "slider.horizontal.3")
                    }.foregroundColor(.textFieldGray)

                }.padding(.horizontal)
                ScrollView {
                    VStack {
                        ForEach(viewModel.filteredRestaurants) { restaurant in
                            RestaurantCardView(viewModel: RestaurantCardViewModel(restaurant: restaurant))
                                .padding(.horizontal)
                                .frame(width: metrics.size.width, height: metrics.size.height / 2.25)
                                .fullScreenCover(item: $restaurantToPresent) { restaurant in
                                    RestaurantDetail(viewModel: RestaurantDetailViewModel(restaurant: restaurant))
                                }
                                .onTapGesture {
                                    restaurantToPresent = restaurant
                                }
                                .clipped()
                        }
                    }
                }
            }.sheet(isPresented: $presentFilters) {
                FiltersView(selectedTags: viewModel.selectedTags) { tags in
                    withAnimation {
                        viewModel.selectedTags = tags
                    }
                }
            }
        }.task {
            await viewModel.onAppear()
        }
    }
}

struct SearchView_Previews: PreviewProvider {
    static var previews: some View {
        SearchView()
    }
}
