//
//  Restaurant.swift
//  Eating Barna
//
//  Created by Joan Martin Martrus on 29/4/22.
//

import Foundation
import CoreLocation

class Restaurant: Identifiable, ObservableObject {
    let id: String
    let title: String
    let place: String
    let price: String
    let description: String
    let imageURL: String
    let latitude: Double?
    let longitude: Double?
    let tags: [Tag]?
    @Published var isFavorite: Bool?
    
    var coordinates: CLLocationCoordinate2D? {
        guard let latitude = self.latitude, let longitude = self.longitude  else {
            return nil
        }
        return CLLocationCoordinate2D(latitude: latitude, longitude: longitude)
    }
    
    init(id: String, title: String,
         place: String,
         price: String = "\(Double(Int.random(in: 10...20)))-\(Double(Int.random(in: 20...50)))€",
         description: String = defaultDesc,
         imageURL: String = "https://source.unsplash.com/random/?food&sig=\(Int.random(in: 0...1000))",
         coordinateX: Double? = nil,
         coordinateY: Double? = nil,
         isFavorite: Bool? = nil) {
        self.id = id
        self.title = title
        self.place = place
        self.price = price
        self.description = description
        self.imageURL = imageURL
        self.latitude = coordinateX
        self.longitude = coordinateY
        self.tags = []
        self.isFavorite = isFavorite
    }

    init(restaurantResponse: RestaurantResponse) {
        self.id = restaurantResponse.id
        self.title = restaurantResponse.name
        self.place = restaurantResponse.tags?.first { $0.tagCategory.name == "neighbourhood" }?.name ?? ""
        self.price = restaurantResponse.priceRange ?? ""
        self.description = restaurantResponse.info ?? ""
        self.imageURL = "https://source.unsplash.com/random/?food&sig=\(Int.random(in: 0...1000))"
        self.latitude = restaurantResponse.lat
        self.longitude = restaurantResponse.lng
        self.tags = restaurantResponse.tags.map { $0.map { Tag(tagReponse: $0) } } ?? []
        self.isFavorite = restaurantResponse.isFavorite
    }
}

typealias Restaurants = [Restaurant]


let defaultDesc = "Rollitos sanos y sabrosos, de papel de pasta de arroz, inspirados en un clásico de la comida oriental. ¡Ve a probarlos a @pandanfastgood! #eatingbarna\n.\n.\n🍤Pandan\n💵 15€/pers.\n📍Travessera de Gràcia, 8\n☎️ 931 280 980"
