//
//  NavigationManager.swift
//  Eating Barna
//
//  Created by Joan Martin Martrus on 1/5/22.
//

import Foundation

class NavigationManager: ObservableObject {
    
    static let shared: NavigationManager = NavigationManager()
    private var userDefaultsManager = UserDefaultsManager.shared

    @Published var currentView: CurrentView

    private init() {
        if userDefaultsManager.getToken() != nil {
            currentView = .tabbar
        } else {
            currentView = .login
        }
    }
    
}

enum CurrentView: Equatable {
    case login
    case tabbar
    case register
    case questionary(questionaryType: QuestionaryType)
    indirect case transition(view: CurrentView)
}

enum QuestionaryType {
    case neighbourhood
    case foodType

    var filterString: String {
        switch self {
        case .neighbourhood:
            return "neighbourhood"
        case .foodType:
            return "type"
        }
    }

    var question: String {
        switch self {
        case .neighbourhood:
            return "¿Cuales son los barrios que mas frecuentas?"
        case .foodType:
            return "¿Que tipos de comida te gustan mas?"
        }
    }

    var nextView: CurrentView {
        switch self {
        case .neighbourhood:
            return .transition(view:.questionary(questionaryType: .foodType))
        case .foodType:
            return .tabbar
        }
    }
}
